# AXActionConstants.h Documentation

## Overview
This header defines the string constants used to specify actions that can be performed on accessibility objects.

## Constants

| Constant Name | Description |
| :--- | :--- |
| `kAXCancelAction` | Simulates pressing a Cancel button. |
| `kAXConfirmAction` | Simulates pressing the Return key. |
| `kAXDecrementAction` | Decrements the value of the accessibility object. |
| `kAXIncrementAction` | Increments the value of the accessibility object. |
| `kAXPickAction` | Selects the accessibility object. |
| `kAXPressAction` | Simulates a single click, such as on a button. |
| `kAXRaiseAction` | Causes a window to become as frontmost as is allowed. |
| `kAXShowAlternateUIAction` | Shows an alternate UI. |
| `kAXShowDefaultUIAction` | Shows the default UI. |
| `kAXShowMenuAction` | Shows a menu. |
